@@ -5,9 +5,9 @@
 ;; Author: Jethro Kuan <jethrokuan95@gmail.com>
 ;; URL: https://github.com/org-roam/org-roam
 ;; Keywords: org-mode, roam, convenience
-;; Package-Version: 20260103.1921
-;; Package-Revision: b95d04cbd223
-;; Package-Requires: ((emacs "26.1") (compat "30.1") (dash "2.13") (org "9.6") (emacsql "4.1.0") (magit-section "3.0.0"))
+;; Package-Version: 20260209.1028
+;; Package-Revision: b4857fd7a140
+;; Package-Requires: ((emacs "26.1") (compat "30.1") (org "9.6") (emacsql "4.1.0") (magit-section "3.0.0"))
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -72,7 +72,6 @@
 ;; majority of them can be found at https://github.com/org-roam and MELPA.
 ;;
 ;;; Code:
-(require 'dash)
 
 (require 'rx)
 (require 'seq)
@@ -252,11 +251,6 @@ If BUFFER is not specified, use the current buffer."
            (setq path (buffer-file-name (buffer-base-buffer)))
            (org-roam-file-p path)))))
 
-(defun org-roam-buffer-list ()
-  "Return a list of buffers that are Org-roam files."
-  (--filter (org-roam-buffer-p it)
-            (buffer-list)))
-
 (defun org-roam--file-name-extension (filename)
   "Return file name extension for FILENAME.
 Like `file-name-extension', but does not strip version number."
@@ -295,12 +289,12 @@ Use external shell commands if defined in `org-roam-list-files-commands'."
 (defun org-roam--shell-command-files (cmd)
   "Run CMD in the shell and return a list of files.
 If no files are found, an empty list is returned."
-  (--> cmd
-       (shell-command-to-string it)
-       (ansi-color-filter-apply it)
-       (split-string it "\n")
-       (seq-filter (lambda (s)
-                     (not (or (null s) (string= "" s)))) it)))
+  (thread-last cmd
+               shell-command-to-string
+               ansi-color-filter-apply
+               (funcall (lambda (str) (split-string str "\n")))
+               (seq-filter (lambda (s)
+                             (not (or (null s) (string= "" s)))))))
 
 (defun org-roam--list-files-search-globs (exts)
   "Given EXTS, return a list of search globs.
